Package: priceR
Type: Package
Title: Economics and Pricing Tools
Version: 1.0.4
Imports: dplyr, gsubfn, stringr, purrr, jsonlite, stats, lubridate,
        stringi, tidyr
Authors@R: c(person(given="Steve", family="Condylios",
    role=c("aut", "cre"), email="steve.condylios@gmail.com",
    ),
    person(given="Bruno", family="Mioto", role="ctb", email="brunomioto97@gmail.com"),
    person(given = "Bryan", family = "Shalloway", role = "ctb", email = "brshallodev@gmail.com"))
Maintainer: Steve Condylios <steve.condylios@gmail.com>
BugReports: https://github.com/stevecondylios/priceR/issues
License: MIT + file LICENSE
URL: https://github.com/stevecondylios/priceR
Description: Functions to aid in micro and macro economic analysis and handling of price and
    currency data. Includes extraction of relevant inflation and exchange rate data from World Bank
    API, data cleaning/parsing, and standardisation. Inflation adjustment
    calculations as found in Principles of Macroeconomics by Gregory Mankiw et al (2014). Current
    and historical end of day exchange rates for 171 currencies from the European Central Bank
    Statistical Data Warehouse (2020).
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat
LazyData: true
NeedsCompilation: no
Packaged: 2026-05-11 03:33:12 UTC; st
Author: Steve Condylios [aut, cre],
  Bruno Mioto [ctb],
  Bryan Shalloway [ctb]
Repository: CRAN
Date/Publication: 2026-05-11 03:50:02 UTC
Built: R 4.6.0; ; 2026-05-11 06:54:38 UTC; unix
