# Generated by roxygen2: do not edit by hand

export(adjust_for_inflation)
export(afi)
export(append_exchangeratehost_access_key)
export(convert_currencies)
export(convert_to_iso2Code)
export(country_input_type)
export(currencies)
export(currency_characters)
export(currency_to_numeric)
export(exchange_rate_latest)
export(extract_salary)
export(format_currency)
export(format_dollars)
export(from_to_dates_rates)
export(historical_exchange_rates)
export(pminmax)
export(retrieve_inflation_data)
export(round_down_to_nearest)
export(round_to_nearest)
export(round_up_to_nearest)
export(show_countries)
export(url_all_results)
import(dplyr)
import(gsubfn)
import(purrr)
import(stringi)
import(stringr)
importFrom(jsonlite,fromJSON)
importFrom(purrr,map_df)
importFrom(stats,na.omit)
importFrom(utils,stack)
