#' @description priceR: Economics and Pricing Tools
#' @docType package
#'
#' @details
#' It has the goal of providing a quick and practical way of extracting numeric price and currency data from text fields, thus allowing faster and easier analysis of ostensibly numeric data.
#'
#'
#' @author Steve Condylios \email{steve.condylios@gmail.com}
#'
#'
#'
#' @name priceR-package
#'
# NULL
# From jennybc's comment here: https://github.com/STAT545-UBC/Discussion/issues/451
# quiets concerns of R CMD check re: the .'s that appear in pipelines
if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))


