library(jsonlite)
library(dplyr)
library(purrr)
library(testthat)
# options(digits = 22)

# Note that this .R script doesn't know about functions in priceR
# So let's change that

# print(getwd())
# Note: this will be executed from: /tests/testthat"
# source("../../R/adjust_for_inflation.R")




# # Assign these variables once
# country <- "AU"
# inflation_dataframe <- retrieve_inflation_data(country)
# countries_dataframe <- show_countries()
#
#
# # Required for some error messages
# available_inflation_data <- inflation_dataframe %>% na.omit
#
# price <- 10
#

