% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/round_to_nearest.R
\name{round_up_to_nearest}
\alias{round_up_to_nearest}
\title{Round prices up to the nearest specified increment}
\usage{
round_up_to_nearest(amount, to_nearest)
}
\arguments{
\item{amount}{Price to be rounded}

\item{to_nearest}{Increment to which price is to be rounded up to}
}
\description{
Round prices up to the nearest specified increment
}
\examples{

# Round up to nearest 0.05 (5c)
library(dplyr)
prices <- c(4.45, 5.22, 0.16, 27.88, 112.19)
prices \%>\% round_up_to_nearest(0.05)


# Round up to nearest $10
prices <- c(4.45, 5.22, 0.16, 27.88, 112.19)
prices \%>\% round_up_to_nearest(10)
}
